==> jc-1.4.0.tar.gz: java/awt/event/ContainerEvent.h <==
// public class java.awt.event.ContainerEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class b243f227ef4eecc7 java_awt_event_ContainerEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_ContainerEvent_H_
#define _JC_java_awt_event_ContainerEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ContainerEvent$sub_refs	_jc_java_awt_event_ContainerEvent$sub_refs;
typedef struct _jc_java_awt_event_ContainerEvent$sub_nonrefs	_jc_java_awt_event_ContainerEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ContainerEvent$refs	_jc_java_awt_event_ContainerEvent$refs;
typedef struct _jc_java_awt_event_ContainerEvent$nonrefs	_jc_java_awt_event_ContainerEvent$nonrefs;
typedef struct _jc_java_awt_event_ContainerEvent$object	_jc_java_awt_event_ContainerEvent$object;

typedef struct _jc_java_awt_event_ContainerEvent$fields_struct	_jc_java_awt_event_ContainerEvent$fields_struct;
typedef const struct _jc_java_awt_event_ContainerEvent$vmethods	_jc_java_awt_event_ContainerEvent$vmethods;
typedef const struct _jc_java_awt_event_ContainerEvent$vtable	_jc_java_awt_event_ContainerEvent$vtable;
typedef const struct _jc_java_awt_event_ContainerEvent$vtype	_jc_java_awt_event_ContainerEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ContainerEvent$fields_struct {
	jlong	serialVersionUID;
	jint	COMPONENT__5fADDED;
	jint	COMPONENT__5fREMOVED;
	jint	CONTAINER__5fFIRST;
	jint	CONTAINER__5fLAST;
};
extern _jc_java_awt_event_ContainerEvent$fields_struct _jc_java_awt_event_ContainerEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ContainerEvent$method$_init$2b460ae648d6c5b9(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *);

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_ContainerEvent$method$getChild$1fafdb78d92a6fdb(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);
extern struct _jc_java_awt_Container$object *_jc_java_awt_event_ContainerEvent$method$getContainer$b41eecd3d62ddbe0(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ContainerEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$getChild$1fafdb78d92a6fdb;
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$getContainer$b41eecd3d62ddbe0;
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ContainerEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getChild$1fafdb78d92a6fdb)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);
	struct _jc_java_awt_Container$object	*(*getContainer$b41eecd3d62ddbe0)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ContainerEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_ContainerEvent$vmethods	java_awt_event_ContainerEvent;
};

// Vtype
struct _jc_java_awt_event_ContainerEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ContainerEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ContainerEvent$sub_refs {
	struct _jc_java_awt_Component$object	*child;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ContainerEvent$refs {
    _jc_java_awt_event_ContainerEvent$sub_refs	java_awt_event_ContainerEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ContainerEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ContainerEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_ContainerEvent$sub_nonrefs	java_awt_event_ContainerEvent;
};

// Object instance structure
struct _jc_java_awt_event_ContainerEvent$object {
	_jc_java_awt_event_ContainerEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ContainerEvent$vtype	*vtype;
	_jc_java_awt_event_ContainerEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ContainerEvent$vtype _jc_java_awt_event_ContainerEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ContainerEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ContainerEvent$class_object;

#endif	/* _JC_java_awt_event_ContainerEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/ContainerEvent.h <==
// public class java.awt.event.ContainerEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class b243f227ef4eecc7 java_awt_event_ContainerEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_ContainerEvent_H_
#define _JC_java_awt_event_ContainerEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ContainerEvent$sub_refs	_jc_java_awt_event_ContainerEvent$sub_refs;
typedef struct _jc_java_awt_event_ContainerEvent$sub_nonrefs	_jc_java_awt_event_ContainerEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ContainerEvent$refs	_jc_java_awt_event_ContainerEvent$refs;
typedef struct _jc_java_awt_event_ContainerEvent$nonrefs	_jc_java_awt_event_ContainerEvent$nonrefs;
typedef struct _jc_java_awt_event_ContainerEvent$object	_jc_java_awt_event_ContainerEvent$object;

typedef struct _jc_java_awt_event_ContainerEvent$fields_struct	_jc_java_awt_event_ContainerEvent$fields_struct;
typedef const struct _jc_java_awt_event_ContainerEvent$vmethods	_jc_java_awt_event_ContainerEvent$vmethods;
typedef const struct _jc_java_awt_event_ContainerEvent$vtable	_jc_java_awt_event_ContainerEvent$vtable;
typedef const struct _jc_java_awt_event_ContainerEvent$vtype	_jc_java_awt_event_ContainerEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ContainerEvent$fields_struct {
	jlong	serialVersionUID;
	jint	COMPONENT__5fADDED;
	jint	COMPONENT__5fREMOVED;
	jint	CONTAINER__5fFIRST;
	jint	CONTAINER__5fLAST;
};
extern _jc_java_awt_event_ContainerEvent$fields_struct _jc_java_awt_event_ContainerEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ContainerEvent$method$_init$2b460ae648d6c5b9(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_ContainerEvent$method$getChild$1fafdb78d92a6fdb(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Container$object *_jc_java_awt_event_ContainerEvent$method$getContainer$b41eecd3d62ddbe0(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ContainerEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$getChild$1fafdb78d92a6fdb;
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$getContainer$b41eecd3d62ddbe0;
extern _jc_method _jc_java_awt_event_ContainerEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ContainerEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getChild$1fafdb78d92a6fdb)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Container$object	*(*getContainer$b41eecd3d62ddbe0)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ContainerEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_ContainerEvent$vmethods	java_awt_event_ContainerEvent;
};

// Vtype
struct _jc_java_awt_event_ContainerEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ContainerEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ContainerEvent$sub_refs {
	struct _jc_java_awt_Component$object	*child;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ContainerEvent$refs {
    _jc_java_awt_event_ContainerEvent$sub_refs	java_awt_event_ContainerEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ContainerEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ContainerEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_ContainerEvent$sub_nonrefs	java_awt_event_ContainerEvent;
};

// Object instance structure
struct _jc_java_awt_event_ContainerEvent$object {
	_jc_java_awt_event_ContainerEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ContainerEvent$vtype	*vtype;
	_jc_java_awt_event_ContainerEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ContainerEvent$vtype _jc_java_awt_event_ContainerEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ContainerEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ContainerEvent$class_object;

#endif	/* _JC_java_awt_event_ContainerEvent_H_ */
